@@ -27,7 +27,7 @@ _KNOWN_OPERATIONS_STRINGS = {
 _KNOWN_OPERATIONS: int = functools.reduce(operator.or_, _KNOWN_OPERATIONS_STRINGS.keys())
 _KNOWN_OPERATIONS_PHASES = git.remote.RemoteProgress.BEGIN | git.remote.RemoteProgress.END
 
-_CARET_UP = '\033[1A'  # TODO: works only in bash, but what about cmd?
+_CARET_UP = '\033[1A'
 
 _LOG = logging.getLogger(__name__)
 
@@ -38,7 +38,8 @@ def _create_operation_strings(op_code: int):
     for key, value in _KNOWN_OPERATIONS_STRINGS.items():
         if op_code & key:
             operation_strings.append(value)
-    unknown_operations = op_code & ~_KNOWN_OPERATIONS  # pylint: disable=invalid-unary-operand-type
+    unknown_operations = (
+        op_code & ~_KNOWN_OPERATIONS)  # pylint: disable = invalid-unary-operand-type
     if unknown_operations:
         operation_strings.append(
             f'unknown operation code(s): {unknown_operations} ({unknown_operations:032b})')
